/*
  jQuery Colorbox language configuration
  language: Romanian (ro)
  translated by: shurub3l
*/
jQuery.extend(jQuery.colorbox.settings, {
	current: "imagine {current} din {total}",
	previous: "precedenta",
	next: "următoarea",
	close: "închideți",
	xhrError: "Acest conținut nu poate fi încărcat.",
	imgError: "Această imagine nu poate fi încărcată",
	slideshowStart: "începeți prezentarea (slideshow)",
	slideshowStop: "opriți prezentarea (slideshow)"
});