<?php

// Zenphoto theme definition file
$theme_description['name'] = ucfirst(basename(dirname(__FILE__)));
$theme_description['author'] = gettext('<a href="http://www.noscope.com" target="_blank">Joen Asmussen</a> and <a href="http://www.levibuzolic.com" target="_blank">Levi Buzolic</a>');
$theme_description['version'] = true;
$theme_description['date'] = true;
$theme_description['desc'] = gettext("The simplest Zenphoto theme in 4 distinct flavors. After choosing this theme you can pick the theme color by going to the Admin -> Options tab (or click the link below) and changing the <em>Theme colors</em> option.");
$theme_description['deprecated'] = true;
?>