@charset "UTF-8";
/*
 * jQuery File Upload UI Plugin NoScript CSS
 * https://github.com/blueimp/jQuery-File-Upload
 *
 * Copyright 2012, Sebastian Tschan
 * https://blueimp.net
 *
 * Licensed under the MIT license:
 * https://opensource.org/licenses/MIT
 */

.fileinput-button i,
.fileupload-buttonbar .delete,
.fileupload-buttonbar .toggle {
  display: none;
}
