/*
	jQuery Colorbox language configuration
	language: Russian (ru)
	translated by: Marfa
	site: themarfa.name
*/
jQuery.extend(jQuery.colorbox.settings, {
	current: "изображение {current} из {total}",
	previous: "назад",
	next: "вперёд",
	close: "закрыть",
	xhrError: "Не удалось загрузить содержимое.",
	imgError: "Не удалось загрузить изображение.",
	slideshowStart: "начать слайд-шоу",
	slideshowStop: "остановить слайд-шоу"
});