/* !important
	Zenpage Default theme
*/ /* Basics
------------------------------ */
html { /* Moz */
	margin: 0;
	padding: 0;
	font-family: "Helvetica Neue", "Lucida Grande", Arial, Helvetica, sans-serif;
	color: #222;
}

a {
	outline: none;
}

input, textarea {
	border: 1px solid #E7F0F5;
	background-color: #f1f1f1;
}
h1, h2, h3, h4 {
font-family: Times, "Times New Roman", Georgia, serif;
}

/* Main Layout
------------------------------ */
body {
	background-color: black; /* #DBDBDB;*/
	font-size: 62.5%;
}

#main {
	padding-top: 0;
	width: 950px;
	margin: 0 auto;
}

#header {
	width: 950px;
	height: 127px;
	background-image: url(images/header.jpg);
	background-repeat: no-repeat;
	margin: 0;
	padding: 0;
}

#header h1 {
	position: relative;
	top: 55px;
	left: 40px;
	text-align: left;
	font-size: 2.4em;
	color: black;
	/* color: #82996F; */
	font-weight: normal;
	letter-spacing: 0.1em;
}

#breadcrumb {
	width: 904px;
	height: 1.5em;
	/* background-color: gray; */
	margin-left: 5px;
	font-size: 1.3em;
	padding-top: 7px;
	padding-bottom: 4px;
	padding-right: 0;
	padding-left: 37px;
	border-bottom: 1px solid darkgray;
	border-top: 1px solid darkgray;
	color: white;
	background-image:url(images/breadcrumb-back.jpg);
}

#breadcrumb h2 {
	margin: 0;
	padding: 0;
	font-size: 1em;
	font-weight: normal;
	float: left;
	width: 590px;
	font-family: "Helvetica Neue", "Lucida Grande", Arial, Helvetica, sans-serif;
}

#breadcrumb a {
	text-align: right;
	color: #D1E079;
	border-bottom: 0px dashed white;
}

#breadcrumb a:hover {
	color: white;
}

#content {
	width: 950px;
	background-image: url(images/body.jpg);
	background-repeat: repeat-y;
}

#content-error {
	width: 890px;
	padding: 45px 25px 45px 25px;
	background-color: white;
	font-size: 13px;
	margin-left: 5px;
}

#content-left {
	width: 590px;
	height: 100%;
	float: left;
	margin-top: 2em;
	margin-bottom: 2em;
	padding-top: 0.8em;
	padding-left: 3.6em;
	padding-right: 0em;
	font-size: 13px;
	line-height: 1.6em;
}
#content-left h3, #content-left h2 {
	font-size: 18px;
	line-height: 18px;
	margin-bottom: 0.3em;
	font-weight: normal;
	color: black;
}

#content-left h2 {
	font-size: 20px;
	line-height: 24px;
	color: black;
}

/* "Show more results" link for search */
#content-left h3 small {
	font-size: 13px;
	font-weight: normal;
	}


#content-left h4 {
	margin-bottom: 10px;
	font-weight: normal;
	font-size: 13px;
}
	


#content-left p {
	font-size: 13px;
	line-height: 1.5em;
	margin-bottom: 1em;
	clear: both;
}

#content-left p.zenpageexcerpt {
	font-size: 13px;
	line-height: 1.5em;
	margin: 0px;
	clear: both;
}

#content-left .newsarticle p {
	clear: none;
}

#content-left ul.searchresults li {
	margin-bottom: 8px;
}

#sidebar {
	width: 280px;
	height: 100%;
	float: right;
	background-color: transparent;
	margin-right: 4px;
	border-top: 0px dashed red;
}

.menu {
	margin-top: 0em;
	font-size: 13px;
	padding: 1em 0 0.8em 1em;
	border-bottom: 1px dashed darkgray;
	height: 100%;
}

.menu h3 {
	font-size: 15px;
	font-weight: normal;
	text-transform: capitalize;
	letter-spacing: 0.1em;
	color: black;
	margin-bottom: 0.5em;
	margin-top: 0.7em;
	margin-left: 1.6em;
	border: 0px solid gray;
	font-style: italic;
	background-image: none;
}

.menu ul {
	list-style: none;
	padding-left: 1.8em;
	padding-right: 1em;
	margin-top: 0.2em;
	font-size: 13px;
}

.menu ul li {
	padding-left: 20px;
	padding-bottom: 2px;
	background-image: url(images/arrow_right.gif);
	background-repeat: no-repeat;
	background-position: 1px 0px;
}

.menu ul li.menu_menulabel {
	padding-left: 0px;
	font-family: Times, "Times New Roman", Georgia, serif;
	font-size: 15px;
	font-weight: normal;
	text-transform: capitalize;
	letter-spacing: 0.1em;
	color: black;
	margin-bottom: 0.5em;
	margin-top: 0.9em;
	margin-left: 0em;
	border: 0px solid gray;
	font-style: italic;
	background-image: none;
}

.submenu {
	list-style: none;
	margin-left: -25px;
	padding: 0px;
}

.menu ul li.menu_menulabel ul.submenu li {
		font-size: 13px;
	letter-spacing: 0;
		font-style: normal;
	font-family: "Helvetica Neue", "Lucida Grande", Arial, Helvetica, sans-serif;
}

#footer {
	width: 950px;
	height: 35px;
	padding-top: 6px;
	background-image: url(images/footer.jpg);
	background-repeat: no-repeat;
	text-align: center;
	clear: both;
	font-size: 1.2em;
}

.menu-active-1 .submenu li.menu_image {
	display: none;
}
.menu li.menu-active-1 > a,
.menu li.menu-active a,
.menu li a.menu-active {
	color: #002E5B; 
}

/* Link Styles
------------------------------ */
a:link {
	text-decoration: none;
	color: #82996F;
	border-bottom: 0px dashed;
}

a:visited {
	text-decoration: none;
	color: #82996F;
	border-bottom: 0px dashed;
}

a:active {
	text-decoration: none;
	color: #002E5B;
	border-bottom: 0px dashed;
}

a:hover {
	text-decoration: none;
	color: #002E5B;
	border-bottom: 0px dashed;
}

/* Miscellaneous
------------------------------ */
img {
	border: 0;
}

blockquote {
	border-left: 1px dashed #96967E;
	margin-left: 20px;
	padding-left: 20px;
	color: #363630;
}

#imagemetadata {
	text-align: right;
}

#imagemetadata table {
	text-align: left;
	line-height: 1em;
	border: 1px solid #ccc;
	top: 2em;
	right: 0px;
	background-color: #fafafa;
}

#imagemetadata table td {
	border-bottom: 1px solid #f0f0f0;
	background-color: #f8f8f8;
	padding: 2px 5px;
}

/* Page Navigation
------------------------------ */
ul.pagelist {
	font-size: 13px;
	clear: both;
	padding: 0;
	margin: 10px 0 10px 0;
	list-style-type: none;
}

ul.pagelist li {
	display: inline;
}

ul.pagelist li a,ul.pagelist span.disabledlink {
	padding: 4px;
}

ul.pagelist li.current a {
	font-weight: normal;
	text-decoration: none;
	cursor: default;
	color: black;
}

ul.pagelist li.prev {
	margin-right: 10px;
}

ul.pagelist li.next {
	margin-left: 10px;
}

.disabledlink {
	color: #ddd;
	cursor: default;
}

.pagenav {
	clear: both;
}

.disabled_nav {
	visibility: hidden;
}

/* AJAX
------------------------------ */
#albumDescEditable,#albumTagsEditable {
	margin-bottom: 12px;
}

#imageDescEditable,#albumTagsEditable {
	margin-top: 24px;
}

#imageDesc {
	margin-bottom: 4px;
}

#exif_link {
	float: left;
}
#exif_link a {
	background-color:#f1f1f1;
	text-align:center;
	padding:8px;
	margin-left: 5px;
}


/* Tags
------------------------------ */
.taglist {
	margin: 0;
	padding: 0;
	display: inline;
	list-style-type: none;
}

.taglist li {
	list-style-type: none;
	padding: 0px;
	display: inline;
	color: #999999;
	display: inline;
	list-style-type: none;
}

.tags_title {
	background: none;
	padding-right: 5px;
	padding-left: 0;
	float: left; 
}

/* Image Thumbnails
------------------------------ */
#images {
	float: left;
	width: 650px;
	border: 0px solid gray;
}

.imagethumb a,.imagethumb a:hover {
	display: block;
	padding: 7px;
	margin: 0px 6px 12px 0px;
	line-height: 0px;
	border: 1px solid #e6e6e6;
	background-color: #FBFBF8;
}

.imagethumb a:visited {
	background-color: #fcfcfc;
	border: 1px solid #f8f8f8;
}

.imagethumb a:hover {
	background-color: #f3f3f3;
	border: 1px solid #cccccc;
}

.imagethumb {
	float: left;
}

/* Album Thumbnails
------------------------------ */
#albums {
	float: left;
	width: 650px;
	border: 0px solid gray;
	font-size: 10px;
}

.album {
	margin: 0px 16px 15px 0;
	padding: 10px 0px 10px 10px;
	float: left;
	width: 265px;
	border: 1px solid #EEEEEE;
	background: #FBFBF8;
	line-height: 100%;
	height: 95px;
	position: relative;
}

.album a img {

}

.album .thumb {
	text-decoration: none;
	float: left;
	margin-right: 6px;

}

#albums h3 {
	font-size: 15px;
	letter-spacing: 0.1em;
	padding: 0;
	margin: 0px 0px 5px 0px;
}

.albumdesc {
	height: 90px;
	width: 160px;
	float: left;
}

.album p {
	line-height: 12px;
	font-size: 12px;
	padding: 0px 0px 0px;
	margin: 0px;
}

.albumdesc small {
	color: gray;
}



/* Individual Image
------------------------------ */
.image {
	margin: 0;
	padding: 0;
	border: 0;
}

#image {
	text-align: center;
	margin: 0 auto;
	line-height: 0;
	width: 580px;
	font-size: 0.7em;
}


#image div {
	display: block;
	line-height: 17px;
	text-align: left;
	font-size: 13px;
	}

/* centering flowplayer 3 and jPlayer on image.php (and jplayer playlists elsewhere) */
#image .flowplayer,
.jp-audio,
.jp-video {
	margin: 0 auto;
}

.imgnav {
	float: right;
	position: relative;
	width: 280px;
	padding-top: 50px;
	text-align: center;
	border: 0px solid #D5E6EE;
	background: transparent;
	margin-right: 1em;
	font-size: 13px; 
}

.imgnav .imgprevious a {
	display: block;
	width: 32px;
  height: 32px;
  cursor: pointer;
  background: transparent url(images/jcarousel_prev.png) no-repeat 0 0;
	position: relative;
	top: -40px;
	left: 100px;
	padding: 0;
	font-size: 13px;
	text-decoration: none;
	line-height: 180%;
	color: #82996F;
	text-indent: -3000px;
}

.imgnav .imgprevious a:hover {
	text-decoration: none;
	color: #002E5B;
	background-position: -32px 0;
}

.imgnav .imgprevious a:active {
	text-decoration: none;
	color: #002E5B;
	background-position: -64px 0;
}

.imgnav .imgnext a {
	display: block;
	width: 32px;
  height: 32px;
  cursor: pointer;
  background: transparent url(images/jcarousel_next.png) no-repeat 0 0;
	position: relative;
	top: -40px;
	right: 100px;
	padding: 0px 0;
	font-size: 13px;
	text-decoration: none;
	line-height: 180%;
	color: #82996F;
	text-indent: -3000px;
}

.imgnav .imgnext a:hover {
	text-decoration: none;
	color: #002E5B;
	background-position: -32px 0;
}

.imgnav .imgnext a:active {
	text-decoration: none;
	color: #002E5B;
	 background-position: -64px 0;
}


.imgnav .imgprevious a {
	float: left;
}

.imgnav .imgnext a {
	float: right;
}

#narrow {
	width: 580px;
	margin-top: 5px;
}


/* favorites styles */
.album .imageFavorites {
position: absolute;
right: 5px;
bottom: 5px;
z-index: 2000;
}
.imagethumb {
	position: relative;
}

.imagethumb .imageFavorites {
position: absolute;
right: 12px;
bottom: 18px;
z-index: 2000;
}

.imageFavorites input:hover {
cursor: pointer !important;
}

/* Paged thumbs nav
------------------------------ */
#pagedthumbsnav {
	width: 580px;
	height: 55px;
	padding: 0px;
	border: 0px solid gray;
	color: #444444;
}

#pagedthumbsimages {
	text-align: center;
	border: 0px solid gray;
}

#pagedthumbsimages img,
.jcarousel-list li img {
	border: 1px solid darkgray;
	padding: 2px;
	float: left;
}

#pagedthumbsimages img:hover,
.jcarousel-list li img:hover {
	border: 2px solid orange;
	padding: 1px;
}

#pagedthumbsnav-active img {
	border: 2px solid orange;
	padding: 1px;
	float: left;
}

#pagedthumbsnav-prev {
	width: 155px;
	height: 20px;
	padding-top: 10px;
	font-size: 13px;
	float: left;
}

#pagedthumbsnav-next {
	width: 100px;
	height: 20px;
	padding-top: 10px;
	font-size: 13px;
	float: right;
	text-align: center;
}

#pagedthumbsnav-prevdisabled {
	visibility: hidden;
	width: 155px;
	height: 20px;
	padding-top: 10px;
	font-size: 1em;
	float: left;
}

#pagedthumbsnav-nextdisabled {
	visibility: hidden;
	width: 100px;
	height: 20px;
	padding-top: 10px;
	font-size: 13px;
	float: right;
	text-align: center;
}

/* Comments
------------------------------ */
#comments {
	clear: both;
	width: 100%;
	margin-top: 10px;
	padding: 0;
	border-top: 1px dashed darkgray;
	
}

#comments h3 {
	font-size: 15px;
	line-height: 17px;
	margin-top: 0.5em;
	margin-bottom: 0.5em;
	letter-spacing: 0;
	color: black;
}

.comment {
	padding: 0px 8px 12px 8px;
	border: 1px solid #E7F0F5;
	background: #F8F9F2;
	margin-bottom: 12px;

}

.commentmeta {
	margin-bottom: 12px;
}

.commentauthor {
	font-weight: bold;
}

.commentdate {
	margin-top: 12px;
	color: #8DB8CF;
	font-size: 85%;
}

/* jQuery pagination comments */

.Pagination {
	margin-bottom: 10px;
}

.Pagination span.current,
.Pagination span.next,
.Pagination a,
.Pagination a.next {
	padding:0px 4px 0px 4px;
	margin-left: 0px;
	margin-right: 0px;
}

.Pagination span.prev,
.Pagination a.prev {
	padding:0px 4px 0px 0px;
	margin-left: 0;
	margin-right: 0px;
}

/* Forms
------------------------------ */
.inputbox {
	width: 250px;
	padding: 2px;
	border: 1px solid #e5e5e5;
	background-color: #f1f1f1; 
}

textarea {
	padding: 4px;
	width: 100%;
	color: #5A5A4B;
	font: 100%/ 200% "Helvetica Neue", Arial, Helvetica, sans-serif;
	border: 1px solid #e5e5e5;
	background-color: #f1f1f1; 
}

.checkbox {
	cursor: pointer;
}

.button {
	cursor: pointer;
	padding: 5px 10px;
	border: 1px solid #e5e5e5;
	background-color: #f1f1f1; 
}


label {
	cursor: pointer;
}

label:hover {
	color: #000;
}



#map {
	margin-left: -77px;
}

#rating {
	margin-top: 10px;
	clear: left;
}

/* Search Box
------------------------------ */
#search {
	float: right;
	margin-top: 15px;
	margin-right: 70px;
	text-align: center;
	background: transparent;
	z-index: 1000;
	position: relative;
	border: 0px solid darkgray;
	background: transparent;
}

#search input.button {
	padding: 4px;
	font-size: 13px;
	border: 1px solid darkgray;
	background-color: #f1f1f1; 
}

#search ul {
	position: absolute;
	text-align: left;
	width: 20px;
	margin: 0px;
	padding: 0px;
	list-style: none;
	background-color: white;
}

#search ul .item {
	display: none;
	background-color: white;
}

#search ul:hover .item {
	display: block;
	padding: 1px;
	margin: 0px;
	background: #fff
}

#search li {
	width: 150px;
	background-color: white;
}

#searchfields_icon {
	position: relative;
	top: 4px;
}

.clear {
	clear: both;
	height: 10px;
}

/* Archive View
---------------------------- */
#archive {
	width: 580px;
	text-align: left;
}

ul.archive * {
	padding: 0;
	margin: 0;
	list-style: none;
}

ul.archive li {
	display: inline;
	margin-right: 5px;
}

ul.archive .year {
	margin-top: 0px;
	text-align: left;
	font-weight: bold;
	font-size: 13px;
  margin-left: -30px;
  margin-right: 0px;
}

ul.archive .month {
	font-size: 13px;
	list-style: none;
	border-top: 0px solid #E6E6DF;
	padding-top: 5px;
	margin-left: -30px;
	font-weight: normal;
	margin-bottom: 15px;
}



ul.archive .archive-active a {
	color: black;
}

#archive h3 {
	background-color: transparent;
	font-size: 15px;
	letter-spacing: 0.1em;
}

/* Tag Cloud
---------------------------- */
#tag_cloud {
	text-align: center;
	background: #eee;
}

#tag_cloud ul li {
	display: inline;
	list-style-type: none;
}

#tag_cloud p {
	padding: 10px 0;
	margin: 20px 0;
	background: #fff;
	border-top: 3px solid #E6E6DF;
	border-bottom: 3px solid #E6E6DF;
	font-size: 13px;
	font-weight: bold;
	text-align: left;
}

/* Error Messages
------------------------------ */
.error {
	color: #C33;
	font-weight: bold;
}
.errorbox {
	padding: 20px;
	background-color: #FDD;
	border-top: 1px solid #FAA;
	border-left: 1px solid #FAA;
	border-right: 1px solid #FAA;
	border-bottom: 5px solid #FAA;
	margin-bottom: 10px;
	font-size: 13px;
	color: #DD6666;
}

.errorbox h2 {
	color: #DD6666;
	font-size: 100%;
	font-weight: bold;
	margin: 0px;
}
.errorlist {
	list-style-type: none;
}	

/* News Articles
------------------------------ */
hr {
	border: 0;
	border-top: 1px dashed gray;
}

.newsarticle {
	padding-top: 1em;
	padding-bottom: 1em;
	border-bottom: 1px dashed darkgray;
}

.newsarticlecredit {
	margin-top: 0px;
	margin-bottom: 10px;
}

.newsarticlecredit-left {
	float: left;
	margin-right: 0.3em;
}

.newscategories {
	margin: 0;
	padding: 0;
	display: inline;
}

.newscategories li {
	display: inline;
	list-style: none;
}

.singlenews_prev {
	float: left;
}

.singlenews_next {
	float: right;
}

.langselector {
	height: 25px;
}

.langselector p {
	float: left;
}

.newstype {
	font-size: 11px;
}

.langselector {
	margin-top: 0em;
	font-size: 13px;
	padding: 2em 0em 0.8em 3em;
	border-bottom: 0px dashed darkgray;
	height: 100%;
}

#dynamic-locale {
	width: 195px;
}
/* zenphoto/zenpage link
---------------------------*/
#zen-part {
	font-size: 17px;
	font-family: Arial, Helvetica, sans-serif;
}

#photo-part {
	font-size: 9px;
	font-family: Arial, Helvetica, sans-serif;
	font-weight: bold;
}

#IE-clear-part {
	font-size: 13px;
	font-weight: normal;
}

img#captcha {
display: block;
float: left;
margin-bottom: 5px;
}
input#code {
float: left;
margin-left: 10px;
width: 10em !important;
}
#recaptcha_widget_div {
float: left;
}


/* Pretty Buttons
------------------------------------- */
.buttons a,.buttons button {
	display: block;
	float: left;
	margin: 0 7px 0 0;
	background-color: #f5f5f5;
	background-image: url(images/admin-buttonback.jpg);
	background-repeat: repeat-x;
	border: 1px solid #dedede;
	border-top: 1px solid #eee;
	border-left: 1px solid #eee;
	font-family: "Lucida Grande", Tahoma, Arial, Verdana, sans-serif;
	font-size: 13px;
	line-height: 130%;
	text-decoration: none;
	font-weight: bold;
	color: #565656;
	cursor: pointer;
	padding: 5px 10px 6px 7px; /* Links */
}

.buttons button {
	text-decoration: none;
	width: auto;
	overflow: visible;
	padding: 4px 10px 3px 7px; /* IE6 */
}

.buttons button[type] {
	text-decoration: none;
	padding: 5px 10px 5px 7px; /* Firefox */
	line-height: 17px; /* Safari */
}

.buttons button img,.buttons a img {
	text-decoration: none;
	margin: 0 3px -3px 0 !important;
	padding: 0;
	border: none;
	width: 16px;
	height: 16px;
}

/* standard buttons */
button:hover,.buttons a:hover {
	text-decoration: none;
	background-color: #dff4ff;
	border: 1px solid #CBCBCB;
	color: #FF8A00;
}

.buttons a:active {
	text-decoration: none;
	background-color: #6299c5;
	border: 1px solid #6299c5;
	color: #fff;
}

/* positive buttons */
button.positive,.buttons a.positive {
	text-decoration: none;
	color: #529214;
}

.buttons a.positive:hover,button.positive:hover {
	text-decoration: none;
	background-color: #E6EFC2;
	border: 1px solid #f5f5f4;
	color: #529214;
}

.buttons a.positive:active {
	text-decoration: none;
	background-color: #529214;
	border: 1px solid #529214;
	color: #fff;
}

/* negative buttons */
.buttons a.negative,button.negative {
	text-decoration: none;
	color: #d12f19;
}

.buttons a.negative:hover,button.negative:hover {
	text-decoration: none;
	background: #fbe3e4;
	border: 1px solid #fbc2c4;
	color: #d12f19;
}

.buttons a.negative:active {
	text-decoration: none;
	background-color: #d12f19;
	border: 1px solid #d12f19;
	color: #fff;
}

/* slideshowlink */ 

#slideshowlink {
display:block;
margin-bottom: 15px;
float: left;
}

#slideshowlink a {
background-color:#f1f1f1;
width:100px; 
text-align:center;
padding:8px;
}

/* map link */
#maplink {
display:block;
margin-bottom: 15px;
float: left;
}

#maplink a {
background-color:#f1f1f1;
width:100px; 
text-align:center;
padding:8px;
}

/* OpenStreetMap  */
div#osm_map {
	margin: 20px 0;
}

/* Scriptless Social Sharing */
ul.scriptless_socialsharing li {
	display: inline-block !important;
}

/* tinyZenpage title addition */
.zenpage_wrapper_left,
.zenpage_wrapper_right {
border: 1px solid #EEEEEE;
background: #FBFBF8;
padding: 10px;
}

.zenpage_wrapper_left {
margin-right: 10px;
}

.zenpage_wrapper_right {
margin-left: 10px;
}
.zenpage_title {
font-style: italic;
}

/*CSS3 rounded edges */
.album,
.button,
#slideshowlink a,
textarea,
#exif_link a,
#search_input, 
#search_submit,
.zenpage_wrapper_left,
.zenpage_wrapper_right {
	-moz-border-radius: 5px 5px 5px 5px;
	-khtml-border-radius: 5px 5px 5px 5px;
	-webkit-border-radius: 5px 5px 5px 5px;
	border-radius: 5px 5px 5px 5px;
}

ul.flags {
margin: 10px 0px 0 18px;
padding: 0;
}

ul.flags li {
float: left;
width: 24px;
height: 18px;
margin: 3px;
padding: 2px;
}
ul.flags li.currentLanguage {
border: 1px solid gray;
padding: 1px;
}
ul.flags li img {
width: 24px;
height: 16px;
}
.textobject {
	font-size: 13px;
	line-height: 16px;
	text-align: left !important;
	text-decoration: none !important;
	overflow:scroll !important;
}
/* box for important notes
------------------------------ */
.notebox {
	padding: 5px 10px 5px 10px;
	background-color: #FFEFB7;
	border-width: 1px 1px 2px 1px;
	border-color: #FFDEB5;
	border-style: solid;
	margin-bottom: 10px;
	font-size: 13px;
	-moz-border-radius: 5px;
	-khtml-border-radius: 5px;
	-webkit-border-radius: 5px;
	border-radius: 5px;
}

.notebox li {
	list-style-type: none;
}

.notebox h2,.notebox strong {
	color: #663300;
	font-size: 13px;
	font-weight: bold;
	margin-bottom: 1em;
}
/* Messages
------------------------------ */
.messagebox {
	background-color: #C0FFA8;
	padding: 10px 15px 10px 15px;
	border-width: 1px 1px 2px 1px;
	border-color: #8BD37C;
	border-style: solid;
	margin-bottom: 10px;
}

.messagebox h2 {
	color: #006633;
	font-size: 15px;
	font-weight: bold;
	margin-bottom: 1em;
}
/* Login
------------------------------ */
#loginform {
	text-align: left;
	padding: 10px;
	width: 350px;
	margin: 25px auto;
	margin-top: 15%;
	margin-left: 0 auto;
	font-size: 13px;
	background: #F7F8F9;
	border-top: 1px solid #BAC9CF;
	border-left: 1px solid #BAC9CF;
	border-right: 1px solid #BAC9CF;
	border-bottom: 5px solid #BAC9CF;
	-moz-border-radius: 5px 5px 5px 5px;
	-khtml-border-radius: 5px 5px 5px 5px;
	-webkit-border-radius: 5px 5px 5px 5px;
	border-radius: 5px 5px 5px 5px;
}

#loginform fieldset {
	-moz-border-radius: 5px 5px 5px 5px;
	-khtml-border-radius: 5px 5px 5px 5px;
	-webkit-border-radius: 5px 5px 5px 5px;
	border-radius: 5px 5px 5px 5px;
	border: 1px solid lightgray;
	padding:10px;
	text-align:left;
}

#loginform input.textfield {
	margin: 0px;
	width:270px;
	font-size: 13px;
	padding: 4px;
}

.logon_form_text {
	padding: 4px;
	text-align:left;
	margin-left: 10px;
	margin-left: 5px;
}

.logon_link {
	text-align:center;
}

.button {
	cursor: pointer;
	padding: 5px 10px;
}

label {
	cursor: pointer;
}

label:hover {
	color: #000;
}

#registration_form p, #commentform p, #mailform p {
clear: both;
}

#registration_form label,
#commentform label,
#mailform label{
width: 30% !important;
float: left; 
display: block;
}

#registration_form label[for=admin_dataconfirmation],
#commentform label[for=comment_dataconfirmation],
#mailform label[for=dataconfirmation] {
	width: 100% !important;
	float: none;
}

form label strong {
color: red;
}

#registration_form input[type="text"],
#registration_form input[type="password"],
#mailform input[type="text"],
#commentform input[type="text"]{
width: 65%;
}

input.button {
padding: 5px 8px 5px 8px!important;
margin: 5px 0 0 0;
}

#mailform textarea, 
#commentform textarea#comment {
clear: both;
width: 95% !important;
height: 150px;
}

.clearall {
clear: both !important;
}
.clearleft {
clear: left !important;
}
.clearright {
clear: right !important;
}

.bx-wrapper{
	margin: 0 auto;
}

/* reCaptcha
------------------------------ */
.g-recaptcha {
	display: inline-block;
}

/* Featured image
-------------------------------*/

.featurediamge_newslist {
	display: block;
	float: left;
	margin-right: 20px;

}

.featuredimage_singlenews {
	margin-top: 10px;
}