<?php

// force UTF-8 Ø

if($zenpage = extensionEnabled('zenpage')) { // check if Zenpage is enabled or not
	if (checkForPage(getOption("zenpage_homepage")) && ZP_PAGES_ENABLED) { // switch to a news page
		$ishomepage = true;
		include ('pages.php');
	} else {
		include ('gallery.php');
	}
} else {
	include ('gallery.php');
}
?>