/*
	jQuery Colorbox language configuration
	language: Estonian (et)
	translated by: keevitaja
*/
jQuery.extend(jQuery.colorbox.settings, {
	current: "{current}/{total}",
	previous: "eelmine",
	next: "järgmine",
	close: "sulge",
	xhrError: "Sisu ei õnnestunud laadida.",
	imgError: "Pilti ei õnnestunud laadida.",
	slideshowStart: "Käivita slaidid",
	slideshowStop: "Peata slaidid"
});