/*

shared css so we need make them only once.

*/

/* Pretty Buttons
------------------------------------- */
.buttons a,.buttons button {
	display: block;
	float: left;
	margin: 0 7px 0 0;
	background-color: #f5f5f5;
	background-image: url(images/admin-buttonback.jpg);
	background-repeat: repeat-x;
	border: 1px solid #dedede;
	border-top: 1px solid #eee;
	border-left: 1px solid #eee;
	font-family: "Lucida Grande", Tahoma, Arial, Verdana, sans-serif;
	font-size: 100%;
	line-height: 130%;
	text-decoration: none;
	font-weight: bold;
	color: #565656;
	cursor: pointer;
	padding: 5px 10px 6px 7px; /* Links */
	-moz-border-radius: 5px;
	-khtml-border-radius: 5px;
	-webkit-border-radius: 5px;
	border-radius: 5px;
}

.buttons button {
	text-decoration: none;
	width: auto;
	overflow: visible;
	padding: 4px 10px 3px 7px; /* IE6 */
}

.buttons button[type] {
	text-decoration: none;
	padding: 5px 10px 5px 7px; /* Firefox */
	line-height: 17px; /* Safari */
}

.buttons button img,.buttons a img {
	text-decoration: none;
	margin: 0 3px -3px 0 !important;
	padding: 0;
	border: none;
	width: 16px;
	height: 16px;
}

/* standard buttons */
button:hover,.buttons a:hover {
	text-decoration: none;
	background-color: #dff4ff;
	border: 1px solid #CBCBCB;
	color: #FF8A00;
}

.buttons a:active {
	text-decoration: none;
	background-color: #6299c5;
	border: 1px solid #6299c5;
	color: #fff;
}

/* positive buttons */
button.positive,.buttons a.positive {
	text-decoration: none;
	color: #529214;
}

.buttons a.positive:hover,button.positive:hover {
	text-decoration: none;
	background-color: #E6EFC2;
	border: 1px solid #f5f5f4;
	color: #529214;
}

.buttons a.positive:active {
	text-decoration: none;
	background-color: #529214;
	border: 1px solid #529214;
	color: #fff;
}

/* negative buttons */
.buttons a.negative,button.negative {
	text-decoration: none;
	color: #d12f19;
}

.buttons a.negative:hover,button.negative:hover {
	text-decoration: none;
	background: #fbe3e4;
	border: 1px solid #fbc2c4;
	color: #d12f19;
}

.buttons a.negative:active {
	text-decoration: none;
	background-color: #d12f19;
	border: 1px solid #d12f19;
	color: #fff;
}

.buttons .tooltip {
	width: 17em;
	text-align: left;
}

/* Login
------------------------------ */
#loginform {
	text-align: left;
	padding: 10px;
	width: 350px;
	margin: 25px auto;
	margin-top: 15%;
	font-size: 100%;
	background: #F7F8F9;
	border-top: 1px solid #BAC9CF;
	border-left: 1px solid #BAC9CF;
	border-right: 1px solid #BAC9CF;
	border-bottom: 5px solid #BAC9CF;
	-moz-border-radius: 5px 5px 5px 5px;
	-khtml-border-radius: 5px 5px 5px 5px;
	-webkit-border-radius: 5px 5px 5px 5px;
	border-radius: 5px 5px 5px 5px;
}

#loginform fieldset {
	-moz-border-radius: 5px 5px 5px 5px;
	-khtml-border-radius: 5px 5px 5px 5px;
	-webkit-border-radius: 5px 5px 5px 5px;
	border-radius: 5px 5px 5px 5px;
	border: 1px solid lightgray;
	padding:10px;
	text-align:left;
}

#loginform input.textfield {
	margin: 0px;
	width:270px;
	font-size: 100%;
	padding: 4px;
}

.logon_form_text {
	padding: 4px;
	text-align:left;
	margin-left: 10px;
	margin-left: 5px;
}

.logon_link {
	text-align:center;
}

#commentcontent {
	clear: both;
}
