/*
	jQuery Colorbox language configuration
	language: Chinese Simplified (zh-CN)
	translated by: zhao weiming
*/
jQuery.extend(jQuery.colorbox.settings, {
	current: "当前图像 {current} 总共 {total}",
	previous: "前一页",
	next: "后一页",
	close: "关闭",
	xhrError: "此内容无法加载",
	imgError: "此图片无法加载",
	slideshowStart: "开始播放幻灯片",
	slideshowStop: "停止播放幻灯片"
});