@import url("fonts/style.css");

/* Slideshow 
**************/

.slideshow {
 font-size: 13px;
 color: white;
 font-family: Arial, sans-serif;
 clear: both;
 height: auto;
}

/* the list of the control */
.slideshow .slideshow_controls {
  display: block;
  padding: 10px 0 0 0;
  margin: 0 auto;
  width: 176px;
  
}

.slideshow .slideshow_controls a {
text-decoration: none;
}

.slideshow .slideshow_controls li {
  display: inline;
  margin: 0 5px 0 5px;
  font-size: 22px;
}

.slideshow .slide img {
width: 100%;
height: auto;
}

.slideshow .slide .slide_desc {
margin: 5px 0 0 0;
}

#slideshowpage.slideshow_light .cycle-slide {
color: black;
}