<?php

// force UTF-8 Ø

// Zenphoto theme definition file
$theme_description['name'] = 'Zenpage';
$theme_description['author'] = 'Malte Müller (acrylian)';
$theme_description['version'] = true;
$theme_description['date'] = true;
$theme_description['desc'] = gettext("The Zenpage CMS plugin default theme. It does also work without Zenpage installed as a normal theme. It contains extra support for print_album_menu plugin or the menu_manager plugin (one of these should be enabled for album links in the sidebar), the dynamic_locale plugin, the new paged_thumbs_nav plugin and the jCarousel_thumb_nav plugin.");
$theme_description['deprecated'] = true;
?>