/*
	Zen Photo Admin
*/

/* Basics
------------------------------ */
* {
	line-height: 19px;
}

html { /* Force vertical scrollbar to prevent page shift "jog" */
	/* IE */
	overflow-y: scroll;
	/* Moz */
	height: 100%;
	margin-bottom: 0.1em;
}

body {
	font: normal 82% Arial, "Helvetica Neue", Helvetica, sans-serif;
	color: #4B4B4B;
	text-align: center;
	background-color: #f1f1f1;
	background-image: url(../images/admin-headerback.jpg);
	background-repeat: repeat-x;
	margin: 0;
	padding: 0;
}



em {
	color: black;
}


.inlinecode {
	color: #00008B;
	font-size: 12px;
	font-family: Geneva, Courier, monospace;
}

/* Main Layout
------------------------------ */
#logo {
	float: left;
	text-align: left;
	margin: 20px 10px 0px 30px;
	width: 200px;
	height: 47px;
}

#logo img {
	border: 0;
}

#main {
	text-align: left;
	padding: 20px 0;
	clear: both;
}

#footer {
	clear: both;
	color: #597580;
	font-size: 85%;
	margin: 8px 30px 0px;
	padding-bottom: 15px;
	text-align: right;
}

#footer a {
	color: #4D76CF;
	text-decoration: none;
	border-bottom: 1px dotted #597580;
}

#footer a:hover {
	color: #FF8A00;
	text-decoration: none;
	border-bottom: 1px solid #FF8A00;
}

.scrollup {
	position:fixed;
	bottom:45px;
	right:5px;
	display:block;
	background: #191818;
	color:#fff;
	outline: none !important;
	z-index:1000;
	border-radius:45px;
	padding: 0.3em 0.8em 0.3em 0.8em;
	border: 0;
	font-size: 1.4em;
}

.scrollup:hover,
.scrollup:active,
.scrollup:focus {
	border: 0;
	color: black;
	text-decoration:none;
	background: lightgray;
}

#links {
	float: right;
	font-size: 100%;
	margin: 40px 30px 0 0;
}

#links a {
	color: #4D76CF;
	text-decoration: none;
	border-bottom: 1px dotted #597580;
}

#links a:hover {
	color: #FF8A00;
	text-decoration: none;
	border-bottom: 1px solid #FF8A00;
}

#content {
	padding: 20px 30px 50px 30px;
	background-color: #fff;
	border-top: 1px solid #CBCBCB;
	border-bottom: 5px solid #CBCBCB;
}

/* Text Styles
------------------------------ */
h1 {
	color: #000;
	font-size: 136%;
	font-weight: normal;
	margin: 0px 0px 20px 0px;
}

h2 {
	font-size: 100%;
	font-weight: bold;
	margin: 15px 0px 5px 0px;
}

h2.h2_bordered {
	font-weight: bold;
	padding: 4px 12px;
	border-bottom: 2px solid #cccccc;
	background-image: url(../images/admin-headlineback.jpg);
	background-repeat: repeat-x;
}

/* edit page subheadlines like "images" or "albums" */
.subheadline {
	color: #000;
	font-size: 136%;
	font-weight: normal;
	margin: 0px 0px 0px 0px;
}

h3 {
	font-size: 100%;
	font-weight: normal;
	margin: 0px 0px 5px 0px;
}

p {
	/*width: 97%;*/
	margin-bottom: 0.8em;
}

code {
	font-family: Courier, Monaco, monospace;
	font-size: 1.1em;
	color: #00816A;
}

/* Menu
------------------------------ */

/**
 * Horizontal CSS Drop-Down Menu Module - adaption acrylian for Zenphoto
 *
 * @file		dropdown.css
 * @package		Dropdown
 * @version		0.8
 * @type		Transitional
 * @stacks		597-599
 * @browsers	Windows: IE6+, Opera7+, Firefox1+
 *				Mac OS: Safari2+, Firefox2+
 *
 * @link		http://www.lwis.net/
 * @copyright	2006-2008 Live Web Institute
 *
 */
ul.no_bullets, ol.no_bullets {
	list-style: none;
	padding: 0;
	margin: 0 0 0 25px;
}
ul.nav,
ul.nav li,
ul.nav ul {
	list-style: none;
	margin: 0;
	padding: 0;
}

ul.nav {
	position: relative;
	z-index: 100;
	float: left;
	padding: 0;
	_padding: 0 0 0 30px;
	margin: 0 0 0 30px;
	height: 30px;
}

ul.nav li {
	float: left;
	vertical-align: middle;
}


ul.nav li a {
	border-top: 1px solid #CBCBCB;
	border-left: 1px solid #CBCBCB;
	border-right: 1px solid #CBCBCB;
	font-size: 115%;
	display: block;
	float: left;
	padding: 6px 12px;
	margin: 0px 8px 0px 0px;
	text-decoration: none;
	font-weight: normal;
	height: 17px;
	color: #8797A5;
	background: #F8F8F8;
	background-image: url(../images/admin-navtabback.jpg);
	background-repeat: repeat-x;
	_position: relative; /* IE Only */
	_top: 6px; /* IE Only */
	-moz-border-radius: 5px 5px 0px 0px;
	-khtml-border-radius: 5px 5px 0px 0px;
	-webkit-border-radius: 5px 5px 0px 0px;
	border-radius: 5px 5px 0px 0px;
}

ul.nav li.hover,
ul.nav li:hover {
	position: relative;
	z-index: 599;
	cursor: default;
}

ul.nav li a:hover {
	border-top: 1px solid #CBCBCB;
	border-left: 1px solid #CBCBCB;
	border-right: 1px solid #CBCBCB;
	color: black;
	background-color: #F7F8F9;
	height: 21px;
	_height: 24px;
	position: relative;
	top: -3px;
	_top: 1px; /* IE Only */
}

ul.nav li.current a {
	border-top: 1px solid #CBCBCB;
	border-left: 1px solid #CBCBCB;
	border-right: 1px solid #CBCBCB;
	color: black;
	background: none;
	background-color: #fff;
	background-repeat: repeat-x;
	cursor: default;
	height: 21px;
	_height: 24px;
	position: relative;
	top: -3px;
	_top: 1px; /* IE Only */
}

ul.nav li.currentsubtab a {
	border-top: 1px solid #CBCBCB;
	border-left: 1px solid #CBCBCB;
	border-right: 1px solid #CBCBCB;
	color: #4D646F;
	background-color: #fff;
	cursor: default;
	height: 21px;
	_height: 24px;
	position: relative;
	top: -3px;
	_top: 1px; /* IE Only */
}

ul.nav ul {
	visibility: hidden;
	position: absolute;
	top: 30px;
	left: 0;
	z-index: 598;
	width: 100%;

}

ul.nav ul li {
	float: none;

}
/* These are the dropdown sublist entries */
ul.nav ul.subdropdown li a {
	border: 1px solid #CBCBCB;
	-moz-border-radius: 0px;
	-khtml-border-radius: 0px;
	-webkit-border-radius: 0px;
	border-radius: 0px;
	margin: 0;
	padding: 5px;
	top: 0;
	width: 100%;
	min-width: 100px;
	height: auto;
	background: #F8F8F8;
	font-size: 14px;
}

ul.nav ul.subdropdown li a:hover {
	border: 1px solid #CBCBCB;
	margin: 0;
	padding: 5px;
	top: 0;
}

ul.nav ul ul {
	top: 1px;
	left: 99%;
}

ul.nav li:hover > ul {
	visibility: visible;
}


.subnav {
	list-style-type: none;
	padding: 0;
	_padding: 0 0 0 30px;
	margin: 0 0 0 30px;
	height: 30px;

}

.subnav li {
	display: inline;

}

.subnav li a {
	border-top: 1px solid #CBCBCB;
	border-left: 1px solid #CBCBCB;
	border-right: 1px solid #CBCBCB;
	font-size: 115%;
	display: block;
	float: left;
	padding: 6px 12px;
	margin: 0px 8px 0px 0px;
	text-decoration: none;
	font-weight: normal;
	height: 17px;
	color: #8797A5;
	background: #E9ECEF;
	background-image: url(../images/admin-navtabback.jpg);
	background-repeat: repeat-x;
	_position: relative; /* IE Only */
	_top: 6px; /* IE Only */
	-moz-border-radius: 5px 5px 0px 0px;
	-khtml-border-radius: 5px 5px 0px 0px;
	-webkit-border-radius: 5px 5px 0px 0px;
	border-radius: 5px 5px 0px 0px;
}

.subnav li a:hover {
	border-top: 1px solid #CBCBCB;
	border-left: 1px solid #CBCBCB;
	border-right: 1px solid #CBCBCB;
	color: black;
	background-color: #F7F6F8;
	height: 21px;
	_height: 24px;
	position: relative;
	top: -3px;
	_top: 1px; /* IE Only */
}

.subnav li.current a {
	border-top: 1px solid #CBCBCB;
	border-left: 1px solid #CBCBCB;
	border-right: 1px solid #CBCBCB;
	color: black;
	background: none;
	background-color: #FAFAFA;
	cursor: default;
	height: 21px;
	_height: 24px;
	position: relative;
	top: -3px;
	_top: 1px; /* IE Only */
}

.subnav li a:hover {
	border-top: 1px solid #CBCBCB;
	border-left: 1px solid #CBCBCB;
	border-right: 1px solid #CBCBCB;
	color: #000;
	background-color: #F7F8F9;
	height: 21px;
	_height: 24px;
	position: relative;
	top: -3px;
	_top: 1px; /* IE Only */
}


/* Messages
------------------------------ */
.border {
	padding: 10px;
	margin-bottom: 10px;
	font-size: 100%;
	background-color: #FAFAFA !important;
}
.messagebox {
	background-color: #C0FFA8;
	padding: 10px 15px 10px 15px;
	border-width: 1px 1px 1px 1px;
	border-color: #8BD37C;
	border-style: solid;
	margin-bottom: 10px;
}

.messagebox h2 {
	color: #006633;
	font-size: 100%;
	font-weight: bold;
	margin-bottom: 1em;
}

/* Error Messages
------------------------------ */
.error {
	color: #DD6666;
	font-weight: bold;
}

.errorbox {
	padding: 10px 15px 10px 15px;
	background-color:#f2dede;
	border-color:#ebccd1;
	color: #b94a48;
	margin-bottom: 10px;
	font-size: 100%;
}

.errorbox li {
	list-style-type: none;
}

.errorbox h2 {
	color: #DD6666;
	font-size: 100%;
	font-weight: bold;
	margin-bottom: 1em;
}

/* Warning Messages
------------------------------ */
.warningbox {
	padding: 10px 15px 10px 15px;
	background-color: #FFEFB7;
	border-color: #FFDEB5;
	color:black;
	-moz-border-radius: 5px;
	-khtml-border-radius: 5px;
	-webkit-border-radius: 5px;
	border-radius: 5px;
	margin-bottom: 10px;
	font-size: 100%;
	list-style-type: none;
}

.warningbox li {
	list-style-type: none;
}

.warningbox h2 {
	color: #663300;
	font-size: 100%;
	font-weight: bold;
	margin-bottom: 1em;
}

/* box for important notes
------------------------------ */
.notebox {
	padding: 10px 15px 10px 15px;
	background-color:#d9edf7;
	border-color:#bce8f1;
	color: black;
	margin-bottom: 10px;
	font-size: 100%;
	-moz-border-radius: 5px;
	-khtml-border-radius: 5px;
	-webkit-border-radius: 5px;
	border-radius: 5px;
}

.notebox li {
	list-style-type: none;
}

.notebox h2,.notebox strong {
	color: #663300;
	font-size: 100%;
	font-weight: bold;
}

.messagebox > *:last-child, 
.errorbox > *:last-child, 
.warningbox > *:last-child, 
.notebox > *:last-child {
	margin-bottom: 0;
	padding-bottom: 0;
}

/* Miscellaneous
------------------------------ */
a,a em {
	color: #4D76CF;
	text-decoration: none;
}

a img {
	border-width: 1px;
}

a:hover,a:hover em {
	color: #FF8A00;
}

hr {
	height: 0px;
	border: 0px;
	border-bottom: 1px solid #BAC9CF;
	margin: 0.5em 0px;
}

table.noinput {
	width: 100%;
	padding: 0px;
	border-spacing: 1px;
	background: #F1F2F3;
	border: 1px solid #BAC9CF;
}

table.noinput td {
	font-weight: normal;
	font-family: Arial, Helvetica, sans-serif;
	font-size: 110%
}

table.bordered {
	width: 100%;
	padding: 0px;
	border-spacing: 0px;
	background: #E5E5E5;
	border: 1px solid #E5E5E5;
	border-bottom-width: 5px;
	-moz-border-radius: 5px;
	-khtml-border-radius: 5px;
	-webkit-border-radius: 5px;
	border-radius: 5px;
}

table.bordered th {
	font-weight: bold;
	padding: 8px 0px 4px 10px;
	border-bottom: 2px solid #cccccc;
	background: #ECF1F2;
	background-image: url(../images/admin-headlineback.jpg);
	background-repeat: repeat-x;
}

table.bordered .subhead {
	border-top: 1px solid #cccccc;
}

table.bordered tr td {
	padding: 8px 16px;
	margin: 0px;
	background-color: #fff;
	border-bottom: 1px solid #E5E5E5;
}

table.bordered tr.alt1 td {
	background-color: #ECF1F2;
	border-bottom: 2px solid #dddddd;
	background-image: url(../images/admin-headerback.jpg);
	background-repeat: repeat-x;
}

table.bordered table.compact {
	padding: 8px 16px;
	margin: 0px;
}

table.bordered table.compact tr {
	padding: 8px 16px;
	margin: 0px;
}

table.bordered table.compact td {
	padding: 8px 16px;
	margin: 0px;
}

table.options {
	width: 100%;
	padding: 0px;
	border-spacing: 0px;
	background: #E5E5E5;
	border: 1px solid #E5E5E5;
	border-bottom-width: 5px;
	-moz-border-radius: 5px;
	-khtml-border-radius: 5px;
	-webkit-border-radius: 5px;
	border-radius: 5px;
}

table.options th {
	font-weight: bold;
	padding: 8px 0px 4px 10px;
	border-bottom: 2px solid #cccccc;
	background: #ECF1F2;
	background-image: url(../images/admin-headlineback.jpg);
	background-repeat: repeat-x;
}

table.options .subhead {
	border-top: 1px solid #cccccc;
}

table.options td {
	padding: 16px 16px 10px 16px !important;
	vertical-align: top;
}
table.options td p {
	margin-top: 0;
}

table.options tr td {
	padding: 8px 16px;
	margin: 0px;
	background-color: #fff;
	border: none;
}

table.formlayout {
	width: 100%;
}

table.formlayout td {
	padding: 2px;
	vertical-align: top;
}

table.formlayout td.bulk_checkbox {
	width: 21px;
}

table.checkboxes {
	padding: 0px;
	margin: 0px;
	line-height: 10px;
	border: 0px;
}

table.checkboxes tr {
	padding: 0px;
	margin: 0px;
	height: 18px;
}

table.checkboxes td {
	padding: 0px 12px 0px 0px;
	margin: 0px;
}

/* nth-child selector for modern browsers */
table.striped tr:nth-child(even) td {
	background-color: #f4f4f4;
}

.box {
	padding: 4px;
	background-color: #FAFAFA;
	border: 1px solid #E5E5E5;
	border-bottom-width: 5px;
	-moz-border-radius: 5px;
	-khtml-border-radius: 5px;
	-webkit-border-radius: 5px;
	border-radius: 5px;
}
.boxb {
	padding: 4px;
	background-color: LightGray;
	border: 1px solid #E5E5E5;
	border-bottom-width: 5px;
	-moz-border-radius: 5px;
	-khtml-border-radius: 5px;
	-webkit-border-radius: 5px;
	border-radius: 5px;
}

.tabbox {
	padding: 10px;
	background-color: #FAFAFA;
	border: 1px solid #E5E5E5;
	border-bottom-width: 5px;
	-moz-border-radius: 5px;
	-khtml-border-radius: 5px;
	-webkit-border-radius: 5px;
	border-radius: 5px;
}

div.outerbox {
	width: 100%;
	padding: 0px;
	border-spacing: 0px;
	background-color: white;
	border: 1px solid #E5E5E5;
}

.innerbox {
	background: none;
	border: 0px solid #BAC9CF;
	border-bottom-width: 0px;
}

.innerbox_dark {
	background-color: #FAFAFA;
	border: 0px solid #BAC9CF;
	border-bottom-width: 0px;
}

.imagethumb_wrapper {
	width: 110px;
	height: 110px;
	background: #e8e8e8;
	border: 1px solid lightgray;
	padding: 1px;
	margin-bottom: 7px;
	text-align: center;
	display: -webkit-box;  
	display: -moz-flex; 
	display: -ms-flexbox;  
	display: -webkit-flex; 
	display: flex;   
	-webkit-box-align: center;
	-moz-box-align: center;
	-ms-flex-align: center;
	-webkit-align-items: center;
	align-items: center;
	-webkit-justify-content: center;
	-moz-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
}

/* middle and right columns on admin edit pages */
.width100percent { /* workaround to get the album edit table right */
	width: 100%;
}

td.leftcolumn {
	width: 200px;
	min-width:150px;
	white-space: nowrap;
	vertical-align: top;
	text-align:left;
}

td.rightcolumn {
	padding-left: 15px;
	vertical-align: top;
	max-width: 258px;
}

td.rightcolumnmiddle {
	padding-left: 15px;
	vertical-align: top;
	text-align: left;
}

td.middlecolumn {
	vertical-align: top;
	padding-right: 20px !important;
	width: 100%;
}

td.middlecolumn input{
	width: 100%;
}



/* Sortable Images
------------------------------ */
div.ui-sortable img {
	float: left;
}

div.ui-sortable {
	clear: both;
	overflow: hidden;
}

/* Sortable Album Divs
------------------------------ */
td.albumimage {
	width: 45px;
	text-align: right;
}

td.albumtitle {
	width: 250px;
	text-align: left;
}

td.albuminfocolumn {
	width: 150px;
	text-align: right;
}

td.albumicons {
	width: 15px;
	text-align: center;
}

/* edit page icons (originally from Zenpage)
-------------------------------------*/
.icons {
	width: 15px;
	text-align: center;
}

.icons img {
	border: 0px;
}

.icons a {
	outline: none;
}

.icons2 {
	width: 150px;
	text-align: right;
}
.icons2 img {
	border: 0px;
}

.icons2b { /* adjustment for the author column page-admin.php */
	width: 62px;
	text-align: left;
}
.icons2b img {
	border: 0px;
}

.icons3 {
	width: 150px;
	text-align: left;
}
.icons3 img {
	border: 0px;
}

.icons3b {
	width: 145px;
	text-align: left;
}
.icons3b img {
	border: 0px;
}



/* Forms
------------------------------ */
input {
	font-family: Arial, Helvetica, sans-serif;
	font-size: 100%;
}

textarea {
	font-family: Arial, Helvetica, sans-serif;
	font-size: 100%;
}
table.mceLayout td {
	margin: 0 !important;
	padding: 0 !important;
	background-color: transparent !important;
}

input.tags {
	width: 408px;
}

/* Individual Page Styles
------------------------------ */
#home-actions {
	list-style-type: none;
	margin: 0px 0px 0px 10px;
	padding: 0px;
}

#home-actions li {
	margin-bottom: 3px;
	font-size: 100%;
}

.utility_buttons_field {
	padding-left: 0px;
	padding-right: 5px;
	padding-top: 5px;
	padding-bottom: 5px;
	margin: 15px;
	border: 1px solid #cccccc;
	width: 460px;
}

.overview_utility_buttons {
	padding-bottom: 5px;
	width: 220px;
}

.overview-utility {
	width: 500px;
	margin: 0 0 15px 0px;
	padding: 0px;
	float: left;
}

.overview-utility h3,.overview-utility h2 {
	font-weight: bold;
	padding-left: 10px;
	margin: 0;
}

.overview-utility ul {
	width: 480px;
	margin-left: 10px;
	list-style-type: none;
	padding: 0px;
	border-top: 1px solid #dfdfdf;

}

.overview-utility ul li {
	margin-bottom: 0em;
	margin-left: 0px;
	padding: 4px 4px 3px 4px;
	border-bottom: 1px solid #dfdfdf;
}

/* make sure preformatted text wraps in the utility boxes on the Overview page */
.overview-utility pre {
	white-space: pre-wrap;
}

.overview-install-info {
	z-index: 50;
}

.overiew-gallery-stats ul,
.overview-install-info ul {
	border-top: 1px solid #dfdfdf;
}
.overiew-gallery-stats  ul li,
.overview-install-info ul li{
	padding: 4px 1px 3px 1px;
	border-bottom: 1px solid #dfdfdf;
}

.overview-utility fieldset legend {
	margin: 0 5px 0px 5px;
	padding: 0 5px 0 5px;
	font-weight: bold;
}

.overview-utility form {
	max-height: 100px;
	float: left;
	padding-left: 8px;
}

.overview-utility ul.filters,
.overview-utility ul.filters li {
	border: 0px !important;
}

.overview-utility .commentmeta {
	font-size: 90%;
	color: #999;
}

.overview-utility .commentbody {
	font-size: 100%;
}


#albumselect {
	padding: 10px;
	background: #F7F8F9;
	border-top: 1px solid #E5E5E5;
	border-left: 1px solid #E5E5E5;
	border-right: 1px solid #E5E5E5;
	border-bottom: 5px solid #E5E5E5;
	-moz-border-radius: 5px;
	-khtml-border-radius: 5px;
	-webkit-border-radius: 5px;
	border-radius: 5px;
}

#albumselect input {
	padding: 4px;
	font-weight: normal;
	font-size: 100%;
}

.theme_links {
	list-style: none;
}

.theme_links li {
	padding-bottom: 10px;
}

#theme-editor #files {
	float: right;
	border: 1px solid #BAC9CF;
	background: #ECF1F2;
	width: 200px;
}

#theme-editor #files ul {
	list-style-type: none;
	padding: 5px;
	margin-bottom: 5px;
}

#theme-editor #editor {
	margin-right: 210px;
	background: #ECF1F2;
	background: #F7F8F9;
}

#theme-editor #editor form {
	padding: 5px;
}

#theme-editor #editor textarea {
	font-family: Consolas, Monaco, Courier, monospace;
	font-size: 12px;
	width: 99%;
	padding: 3px;
}

acronym {
	cursor: help;
}

/* Login
------------------------------ */
#loginform {
	text-align: left;
	padding: 10px;
	width: 365px;
	margin: 25px auto;
	margin-top: 15%;
	font-size: 100%;
	background: #F7F8F9;
	border-top: 1px solid #BAC9CF;
	border-left: 1px solid #BAC9CF;
	border-right: 1px solid #BAC9CF;
	border-bottom: 5px solid #BAC9CF;
	-moz-border-radius: 5px 5px 5px 5px;
	-khtml-border-radius: 5px 5px 5px 5px;
	-webkit-border-radius: 5px 5px 5px 5px;
	border-radius: 5px 5px 5px 5px;
}

#loginform fieldset {
	-moz-border-radius: 5px 5px 5px 5px;
	-khtml-border-radius: 5px 5px 5px 5px;
	-webkit-border-radius: 5px 5px 5px 5px;
	border-radius: 5px 5px 5px 5px;
	border: 1px solid lightgray;
	padding:10px;
	text-align:left;
}

#loginform input.textfield {
	margin: 0px;
	width:270px;
	font-size: 100%;
	padding: 4px;
}

.logon_form_text {
	padding: 4px;
	text-align:left;
	margin-left: 10px;
	margin-left: 5px;
}

.logon_link {
	text-align:center;
}

label {
	cursor: pointer;
}

label:hover {
	color: #000;
}

/* Thumbnail Preview selectbox effect.
------------------------------------- */
.thumbselect {
	padding-left: 90px;
	background-repeat: no-repeat;
	background-position: center left;
	height: 90px;
}

.thumboption {
	padding-left: 90px;
	height: 40px;
	margin-bottom: 2px;
	background-position: center left;
}

/* language selectbox effect.
------------------------------------- */
.languageselect {
	padding-left: 25px;
	background-repeat: no-repeat;
	background-position: center left;
}

.languageoption {
	padding-left: 25px;
	margin-bottom: 2px;
	background-position: center left;
}

/* language selector
-------------------------------------*/ /* Option Tabs
-------------------------------------*/
.space {
	margin-top: 40px;
}

.ui-tabs-hide {
	display: none;
}

.ui-tabs-nav {
	list-style: none;
	padding: 0;
	margin: 0;
	height: 17px;
}

.ui-tabs-nav li {
	float: left;
}

.ui-tabs-nav a {
	float: left;
	padding: 6px 12px;
	margin: 0px 10px 0px 0px;
	text-decoration: none;
	color: #6b7d84;
	outline: none;
	background: #E9ECEF;
	border-top: 1px solid #C7D3D8;
	border-left: 1px solid #C7D3D8;
	border-right: 1px solid #C7D3D8;
}

.ui-tabs-nav a:hover {
	background-color: #d6dbde;
}

.ui-tabs-nav .ui-tabs-selected a {
	background-color: #d6dbde;
	border-top: 3px solid #6b7d84;
	padding-top: 4px;
	color: #6b7d84;
}

.ui-tabs-disabled {

}

.ui-tabs-panel {
	padding: 1em 0px;
	background: #fff;
	/* declare background color for container to avoid distorted fonts in IE while fading */
}

/* Additional IE specific bug fixes... */
* html .ui-tabs-nav { /* auto clear, @ IE 6 & IE 7 Quirks Mode */
	display: inline-block;
}

* :first-child+html .ui-tabs-nav {
	/* @ IE 7 Standards Mode - do not group selectors, otherwise IE 6 will ignore complete rule (because of the unknown + combinator)... */
	display: inline-block;
}

/* Pretty Buttons
------------------------------------- */
.button {
	cursor: pointer;
	padding: 5px 10px;
}

.buttons a,.buttons button {
	display: block;
	float: left;
	margin: 0 7px 0 0;
	background-color: #f5f5f5;
	background-image: url(../images/admin-buttonback.jpg);
	background-repeat: repeat-x;
	border: 1px solid #dedede;
	border-top: 1px solid #eee;
	border-left: 1px solid #eee;
	font-family: "Lucida Grande", Tahoma, Arial, Verdana, sans-serif;
	font-size: 100%;
	line-height: 130%;
	text-decoration: none;
	font-weight: bold;
	color: #565656;
	cursor: pointer;
	padding: 5px 10px 6px 7px; /* Links */
	-moz-border-radius: 5px;
	-khtml-border-radius: 5px;
	-webkit-border-radius: 5px;
	border-radius: 5px;
}

.buttons button {
	text-decoration: none;
	width: auto;
	overflow: visible;
	padding: 4px 10px 3px 7px; /* IE6 */
}

.buttons button[type] {
	text-decoration: none;
	padding: 5px 10px 5px 7px; /* Firefox */
	line-height: 17px; /* Safari */
}

.buttons button img,.buttons a img {
	text-decoration: none;
	margin: 0 3px -3px 0 !important;
	padding: 0;
	border: none;
	width: 16px;
	height: 16px;
}

/* standard buttons */
button:hover,.buttons a:hover {
	text-decoration: none;
	background-color: #dff4ff;
	border: 1px solid #CBCBCB;
	color: #FF8A00;
}

.buttons a:active {
	text-decoration: none;
	background-color: #6299c5;
	border: 1px solid #6299c5;
	color: #fff;
}

/* positive buttons */
button.positive,.buttons a.positive {
	text-decoration: none;
	color: #529214;
}

.buttons a.positive:hover,button.positive:hover {
	text-decoration: none;
	background-color: #E6EFC2;
	border: 1px solid #f5f5f4;
	color: #529214;
}

.buttons a.positive:active {
	text-decoration: none;
	background-color: #529214;
	border: 1px solid #529214;
	color: #fff;
}

/* negative buttons */
.buttons a.negative,button.negative {
	text-decoration: none;
	color: #d12f19;
}

.buttons a.negative:hover,button.negative:hover {
	text-decoration: none;
	background: #fbe3e4;
	border: 1px solid #fbc2c4;
	color: #d12f19;
}

.buttons a.negative:active {
	text-decoration: none;
	background-color: #d12f19;
	border: 1px solid #d12f19;
	color: #fff;
}

.buttons .fixedwidth {
	text-align: left;
	width: 17em;
}


/*sidebar vertical buttons */
.box-edit .buttons a,
.theme_links .buttons a{
	width: 90% !important;
}

.box-edit select {
	max-width: 100%;
}


/* scrollable checklists
-----------------------------*/
/* Undo some styles from the master stylesheet */
.tagchecklist li {
	background: none;
	padding-left: 0;
	text-align: left;
}

/* CSS for tag checklists */
.tagchecklist hr {
	padding: 0;
	margin-left: 0px;
	margin-right: 0px;
	margin-top: 0px;
	margin-bottom: 0px;
}

.tagchecklist {
	border: 1px solid #ccc;
	list-style: none;
	height: 24em;
	width: 19.5em;
	overflow: auto;
	background-color: white;
}

.tagchecklist,.tagchecklist li {
	margin: 0;
	padding: 0;
	border-bottom: 1px dotted #BAC9CF;
}

.tagchecklist label:hover, .tagchecklist li:hover, .tagchecklist li label.hover {
	background: #F1F2F3;
	color: #333;
}

* html .tagchecklist label {
	height: 1%;
}
.resizeable_tagchecklist li {
	background: none;
	padding-left: 0;
	text-align: left;
	
}
/* CSS for tag checklists */
.resizeable_tagchecklist hr {
	padding: 0;
	margin-left: 0px;
	margin-right: 0px;
	margin-top: 0px;
	margin-bottom: 0px;
}

.resizeable_tagchecklist {
	border: 1px solid #ccc;
	list-style: none;
	height: 24em;
	overflow: auto;
	background-color: white;
	resize: vertical;
}

.resizeable_tagchecklist,.resizeable_tagchecklist li {
	margin: 0;
	padding: 0;
	border-bottom: 1px dotted #BAC9CF;
}

.resizeable_tagchecklist label:hover, .resizeable_tagchecklist li:hover, .resizeable_tagchecklist li label.hover {
	background: #F1F2F3;
	color: #333;
}

* html .resizeable_tagchecklist label {
	height: 1%;
}

#mass_tags_data {
	text-align: left;
	float: left;
}
.tag_div {
	width: 100%;
}

.new_tag {
	border:none;
	text-decoration: none;
	outline: none;
	margin: 0;
	padding: 0;
}
.new_tag img {
	position: relative;
	top: 4px;
	text-decoration: none;
	border:none;
	outline: none;
}
.new_tag a:visited {
	text-decoration: none;
	border:none;
	outline: none;
}
.new_tag a:hover {
	text-decoration: none;
	border:none;
	outline: none;
}
.new_tag a:active {
	text-decoration: none;
	border:none;
	outline: none;
}

/* CSS for tag rename lists */
.tagrenamelist {
	border: 1px solid #ccc;
	list-style: none;
	height: 24em;
	width: 19.2em;
	overflow: auto;
	background-color: white;
	padding-left: 4px;
}

.tagrenamelist,.tagrenamelist li {
	margin: 0;
	border-bottom: 1px dotted #BAC9CF;
}

.tagrenamelist label {
	display: block;
}

.tagrenamelist label:hover,.tagrenamelist label.hover {
	background: #F1F2F3;
	color: #333;
}

* html .tagrenamelist label {
	height: 1%;
}


/* CSS for tag new lists
-----------------------------*/
.tagnewlist {
	border: 1px solid #ccc;
	list-style: none;
	height: 24em;
	width: 19.2em;
	overflow: auto;
	background-color: white;
	padding-left: 4px;
}

.tagnewlist,.tagnewlist li {
	margin: 0;
	border-bottom: 1px dotted #C6D880;
}

.tagnewlist label {
	display: block;
}

.tagnewlist label:hover,.tagnewlist label.hover {
	background: #F1F2F3;
	color: #333;
}

* html .tagnewlist label {
	height: 1%;
}

/* search field checklist */
.searchchecklist {
	border: 1px solid #ccc;
	list-style: none;
	height: 18em;
	width: 350px;
	overflow: auto;
	background-color: white;
	margin: 0;
	padding: 0;
}
.searchchecklist li {
	padding-left: 0;
	text-align: left;
}


/* scrollable checklists
-----------------------------*/
/* Undo some styles from the master stylesheet */
.albumchecklist li {
	background: none;
	padding: 1px 5px 1px 0;
	text-align: left;
	border-bottom: 1px dotted #C6D880;
}

/* CSS for album checklists */
.albumchecklist {
	border: 1px solid #ccc;
	margin: 0;
	padding: 0;
	list-style: none;
	height: 8em;
	overflow: auto;
	width: 458px;
	background-color: white;
}

.albumchecklist label {
	display: block;
}

.albumchecklist label:hover,.albumchecklist label.hover {
	background: #777;
	color: #fff;
}

* html .albumchecklist label {
	height: 1%;
}

/* CSS for custom checklists */
.customchecklist {
	border: 1px solid #ccc;
	list-style: none;
	height: 15em;
	overflow: auto;
	width: 20em;
	background-color: white;
}

.customchecklist li {
	background: none;
	padding-left: 0;
	text-align: left;
}

.customchecklist,.customchecklist li {
	margin: 0;
	padding: 0;
	border-bottom: 1px dotted #C6D880;
}

.customchecklist label {
	display: block;
	padding: 0;
}

.customchecklist label:hover,.customchecklist label.hover {
	background: #777;
	color: #fff;
}

.grouphighlight {
	color: brown;
}

/* CSS for wide checklists */
.fullchecklist {
	border: 1px solid #ccc;
	list-style: none;
	height: 30em;
	overflow: auto;
	background-color: white;
}

.fullchecklist,.fullchecklist li {
	margin: 0;
	padding: 0;
	border-bottom: 1px dotted #C6D880;
}

.fullchecklist label {
	display: block;
	padding: 0;
}

.fullchecklist label:hover,.fullchecklist label.hover {
	background: #777;
	color: #fff;
}


* html .fullchecklist label {
	height: 1%;
}

.unindentedchecklist li {
	background: none;
	padding-left: 0;
	text-align: left;
}

/* CSS for custom unindentedchecklist */
.unindentedchecklist {
	border: 1px solid #ccc;
	list-style: none;
	height: 8em;
	overflow: auto;
	width: 20em;
	background-color: white;
}

.unindentedchecklist,.unindentedchecklist li {
	margin: 0;
	padding: 0;
	border-bottom: 1px dotted #C6D880;
}

.unindentedchecklist label {
	display: block;
	padding: 0;
}

.unindentedchecklist label:hover,.unindentedchecklist label.hover {
	background: #777;
	color: #fff;
}

* html .unindentedchecklist label {
	height: 1%;
}


/* language selector */
.languagelist li {
	background: none;
	padding-left: 0;
	text-align: left;
}

.languagelist {
	border: 1px solid #ccc;
	list-style: none;
	height: 16em;
	resize: vertical;
	overflow: auto;
	width: 350px;
	background-color: white;
}

.languagelist,.languagelist li {
	margin: 0;
	padding: 0;
	border-bottom: 1px dotted #C6D880;
}

/* image pagination on album edit page
-------------------------------------------*/
#imagenav {
	text-align: center;
	background: #ECF1F2;
	border-bottom: 2px solid #BAC9CF;
	background-image: url(../images/admin-headlineback.jpg);
	background-repeat: repeat-x;
}

#imagenavb {
	text-align: center;
	background: #ECF1F2;
	border-top: 2px solid #BAC9CF;
	background-image: url(../images/admin-headlineback.jpg);
	background-repeat: repeat-x;
}

ul.pagelist {
	clear: both;
	padding: 0;
	margin: 0px;
	list-style-type: none;
}

ul.pagelist li {
	display: inline;
}

ul.pagelist li a,ul.pagelist span.disabledlink {
	padding-left: 4px;
	padding-right: 4px;
}

ul.pagelist li.current {
	font-weight: bold;
	text-decoration: none;
	cursor: default;
	color: black;
	padding-left: 4px;
	padding-right: 4px;
}

/* CSS for language_string_list */
.language_string_list {
	border: 1px solid #ccc;
	list-style: none;
	height: 5.5em;
	overflow: auto;
	background-color: white;
}

.language_string_list,.language_string_list li {
	margin: 0;
	padding: 0;
	padding-bottom: 5px;
	border-bottom: 1px dotted #C6D880;
}

/* CSS for language_string_list_short */
.language_string_list_short {
	border: 1px solid #ccc;
	list-style: none;
	height: 5.5em;
	width: 19em;
	overflow: auto;
	background-color: white;
}

.language_string_list_short,.language_string_list_short li {
	margin: 0;
	padding: 0;
	padding-bottom: 5px;
	border-bottom: 1px dotted #C6D880;
}

.language_string_list label_short {
	display: block;
}

.language_string_list label:hover,.language_string_list label.hover {
	background: #F1F2F3;
	color: #333;
}

* html .language_string_list label {
	height: 1%;
}

/* CSS for language_string_listbox
--------------------------------------*/
.language_string_listbox {
	border: 1px solid #ccc;
	list-style: none;
	height: 14em;
	overflow: auto;
	background-color: white;
}

.language_string_listbox,.language_string_listbox li {
	margin: 0;
	padding: 0;
	padding-bottom: 5px;
	border-bottom: 1px dotted #C6D880;
}

.language_string_listbox label {
	display: block;
}

.language_string_listbox label:hover,.language_string_listbox label.hover
{
	background: #F1F2F3;
	color: #333;
}

* html .language_string_listbox label {
	height: 1%;
}

.textarea_hidden {
	position: absolute !important; 
	left: -9999px !important;
}

/* icon legend
------------------*/
.iconlegend {
	height: 20px;
	text-align: right;
}

.iconlegend li {
	display: inline;
	margin-right: 10px;
	white-space: nowrap;
}

.iconlegend li img {
	position: relative;
	top: 3px;
	margin: 0 2px 0 0;
}
.iconlegend-l {
	height: 20px;
	text-align: left;
}

.iconlegend-l li {
	display: inline;
	margin-right: 10px;
	white-space: nowrap;
}

.iconlegend-l li img {
	position: relative;
	top: 3px;
	margin: 0 2px 0 0;
}

.jcExample p {
	width: 400px;
}

#administration {
	float: left;
	text-align: left;
	font-size: 2em;
	text-decoration: none;
}

/* box for edit pages
----------------------------------*/
.h2_bordered_edit {
	width: 18.4em;
	font-weight: bold;
	padding: 5px 8px 5px 8px;
	border-bottom: 2px solid #cccccc;
	border-left: 1px solid #cccccc;
	border-right: 1px solid #cccccc;
	border-top: 1px solid #cccccc;
	background-image: url(../images/admin-headlineback.jpg);
	background-repeat: repeat-x;
	margin-bottom: 0;
	-moz-border-radius: 5px 5px 0 0;
	-khtml-border-radius: 5px 5px 0 0;
	-webkit-border-radius: 5px 5px 0 0;
	border-radius: 5px 5px 0 0;
}

.box-edit {
	margin: 0 0 10px 0;
	padding: 8px;
	background-color: white;
	border: 1px solid #cccccc;
	border-bottom-width: 5px;
	width: 18.4em;
	-moz-border-radius: 0 0 5px 5px;
	-khtml-border-radius: 0 0 5px 5px;
	-webkit-border-radius: 0 0 5px 5px;
	border-radius: 0 0 5px 5px;
}

.checkboxlabel {
	padding-right: .5em;
	float: left;
}

.image_option_tablerow {
	margin:0;
	padding-top:0;
	padding-bottom:5px;
	padding-left:0;
	padding-right:0;
}

.box-edit-unpadded {
	margin: 0 0 10px 0;
	padding: 0px 0px 0px 0px;
	background-color: white;
	border: 1px solid #cccccc;
	border-bottom-width: 5px;
	-moz-border-radius: 0 0 5px 5px;
	-khtml-border-radius: 0 0 5px 5px;
	-webkit-border-radius: 0 0 5px 5px;
	border-radius: 0 0 5px 5px;
}

.box-tags-unpadded {
	width: 19.65em;
	margin: 0 0 10px 0;
	padding: 0px 0px 0px 0px;
	background-color: white;
	border: 1px solid #cccccc;
	border-bottom-width: 5px;
	-moz-border-radius: 0 0 5px 5px;
	-khtml-border-radius: 0 0 5px 5px;
	-webkit-border-radius: 0 0 5px 5px;
	border-radius: 0 0 5px 5px;
}

.tagtext p {
	width: 22em;
	padding-right: 2em;
}

.h2_bordered_albums {
	width: 442px;
	font-weight: bold;
	padding: 5px 8px 5px 8px;
	border-bottom: 2px solid #cccccc;
	border-left: 1px solid #cccccc;
	border-right: 1px solid #cccccc;
	border-top: 1px solid #cccccc;
	background-image: url(../images/admin-headlineback.jpg);
	background-repeat: repeat-x;
	margin: 0;
}

.box-albums-unpadded {
	width: 460px;
	margin: 0 0 10px 0;
	padding: 0px 0px 0px 0px;
	background-color: white;
	border: 1px solid #cccccc;
	border-bottom-width: 5px;
	-moz-border-radius: 5px;
	-khtml-border-radius: 5px;
	-webkit-border-radius: 5px;
	border-radius: 5px;
}


.box-rights {
	width: 460px;
	margin: 0 0 10px 0;
	padding: 0px 0px 0px 0px;
}

fieldset,
.box-rights fieldset {
	padding: 5px;
	border: 1px solid darkgray;
	-moz-border-radius: 05px;
	-khtml-border-radius: px;
	-webkit-border-radius: 5px;
	border-radius: 5px;
	margin-bottom: 5px;
	width: 335px;
}

.box-rights legend {
	font-weight: bold;
	color: black;
}


.box-rights fieldset {
	margin-bottom: 15px;
}

.box-rights fieldset label {
	white-space: nowrap;
	display: block;
	float: left;
}

.box-rights strong {
	display: block;
	margin-bottom: 10px;
}

#logon_box fieldset {
	width: 310px;
	text-align: left;
}

#logon_box input#user,
#logon_box input#pass {
	width: 300px;
}
/* short checklist */
.shortchecklist {
	border: 1px solid #ccc;
	list-style: none;
	resize: vertical;
	height: 10em;
	width: 19.5em;
	overflow: auto;
	background-color: white;
}

.shortchecklist,.shortchecklist li {
	margin: 0;
	padding: 0;
	border-bottom: 1px dotted #BAC9CF;
}

.shortchecklist label {
	display: block;
	padding: 0 0.2em 0 25px;
	text-indent: -25px;
}

.shortchecklist label:hover,.shortchecklist label.hover {
	background: #F1F2F3;
	color: #333;
}

* html .shortchecklist label {
	height: 1%;
}

/* css for the log viewer */
.logtext {
	border-spacing: 1px;
	border: 1px solid #BAC9CF;
	max-height: 55vh;
	overflow-x: scroll; 
}

.logtext p {
	padding: 0;
	margin-top: 0.05em;
	margin-left: 0.5em;
	margin-bottom: 0.05em;
	margin-right: 0.5em;
}

.logtext table {
	overflow-x: scroll;
}

.logtext table th {
	padding-top: 5px;
	padding-bottom: 5px;
	padding-left: 10px;
	padding-right: 10px;
	text-align: center;
	background: #ECF1F2;
}

.logtext table td {
	padding-top: 2px;
	padding-bottom: 2px;
	padding-left: 10px;
	padding-right: 10px;
	text-align: left;
}

.nowrap {
	white-space: nowrap;
}

.log_buttons a,.buttons button {
	display: block;
	float: left;
	margin: 0 7px 0 0;
	background-color: #f5f5f5;
	background-image: url(../images/admin-buttonback.jpg);
	background-repeat: repeat-x;
	border: 1px solid #dedede;
	border-top: 1px solid #eee;
	border-left: 1px solid #eee;
	font-family: "Lucida Grande", Tahoma, Arial, Verdana, sans-serif;
	font-size: 100%;
	line-height: 130%;
	text-decoration: none;
	font-weight: bold;
	color: #565656;
	cursor: pointer;
	padding: 5px 10px 6px 7px; /* Links */
}

.log_buttons button {
	text-decoration: none;
	width: auto;
	overflow: visible;
	padding: 4px 10px 3px 7px; /* IE6 */
}

.log_buttons button[type] {
	text-decoration: none;
	padding: 5px 10px 5px 7px; /* Firefox */
	line-height: 17px; /* Safari */
}

.log_buttons button img,.log_buttons a img {
	text-decoration: none;
	margin: 0 3px -3px 0 !important;
	padding: 0;
	border: none;
	width: 16px;
	height: 16px;
}

/* standard buttons */
button:hover,.log_buttons a:hover {
	text-decoration: none;
	background-color: #dff4ff;
	border: 1px solid #CBCBCB;
	color: #FF8A00;
}

.log_buttons a:active {
	text-decoration: none;
	background-color: #6299c5;
	border: 1px solid #6299c5;
	color: #fff;
}

/* positive buttons */
button.positive,.log_buttons a.positive {
	text-decoration: none;
	color: #529214;
}

.log_buttons a.positive:hover,button.positive:hover {
	text-decoration: none;
	background-color: #E6EFC2;
	border: 1px solid #f5f5f4;
	color: #529214;
}

.log_buttons a.positive:active {
	text-decoration: none;
	background-color: #529214;
	border: 1px solid #529214;
	color: #fff;
}

/* negative buttons */
.log_buttons a.negative,button.negative {
	text-decoration: none;
	color: #d12f19;
}

.log_buttons a.negative:hover,button.negative:hover {
	text-decoration: none;
	background: #fbe3e4;
	border: 1px solid #fbc2c4;
	color: #d12f19;
}

.log_buttons a.negative:active {
	text-decoration: none;
	background-color: #d12f19;
	border: 1px solid #d12f19;
	color: #fff;
}

.log_buttons .tooltip {
	width: 10em;
	text-align: left;
}


.pluginextrashow p.buttons,
.pluginextrahide p.buttons {
	display: inline;
}

.metadata_table {
	width:100%;
	table-layout: fixed;
	word-wrap: break-word;
}

.medtadata_tag {
	width:30%;
	text-align: right;
}

.metadata_container {
	border: 1px solid #BAC9CF;
	width: 100%;
	height: 180px;
	overflow:scroll;
	overflow-x:hidden;
}

.resizeable_metadata {
	height: 240px;
	overflow:scroll;
}

/* Codeblock fields tabs
-------------------------------------------------*/
.codeblock {
	background-color: transparent;
	margin-left: 0px;
}

UL.tabNavigation {
	list-style: none;
	margin: 2px;
	padding: 0;
}

UL.tabNavigation LI {
	display: inline;
}

UL.tabNavigation LI A {
	padding: 3px 5px;
	background-color: #EEEEEE;
	color: #6b7d84;
	text-decoration: none;
	border: 1px solid #C7D3D8;
	-moz-border-radius: 5px 5px 0px 0px;
	-khtml-border-radius: 5px 5px 0px 0px;
	-webkit-border-radius: 5px 5px 0px 0px;
	border-radius: 5px 5px 0px 0px;
}

UL.tabNavigation LI A.selected {
	background-color: white;
	color: black;
	padding: 3px 5px;
}

UL.tabNavigation LI A:hover {
	background-color: white;
	color: gray;
	padding: 3px 5px;
}

UL.tabNavigation LI A:active {
	background-color: white;
	color: black;
	padding: 3px 5px;
}

UL.tabNavigation LI A:focus {
	outline: 0;
	color: #6b7d84;
}

div.tabs>div {
	padding: 0px;
	margin: 0px;
	border: 0px solid #333;
}

div.tabs>div h2 {
	margin: 0;
}

.tabs textarea {
	border: 1px solid #C7D3D8;
	width: 98%;
	height: 150px;
}

/* Extras */
.displayinline {
	display: inline !important;
	white-space:nowrap;
}
.displayinlineright {
	display: inline !important;
	float:right;
	white-space:nowrap;
}
.displayrightsmall {
	float:right;
	white-space:nowrap;
	font-size:85%;
}
.displayleft {
	float:left;
}

.nomargin {
	margin: 0 !important;
}

.nopadding {
	padding: 0 !important;
}

.icon-position-top1 {
	position: relative;
	top: 1px;
}
.icon-position-top3 {
	position: relative;
	top: 3px;
}

.icon-position-top4 {
	position: relative;
	top: 4px;
}

/* icon inline positioning - primarily for the lock icon on Zenpage page passwords */
.icon-position-top8 {
	position: relative;
	top: 8px;
}

.flags {
	padding: 0;
}

.flags img {
	border: none;
	vertical-align: -15%;
}

.flags li {
	display: inline-block;
	padding: 5px;
}

.currentLanguage {
	background: #F7F8F9;
	border-top: 1px solid #BAC9CF;
	border-left: 1px solid #BAC9CF;
	border-right: 1px solid #BAC9CF;
	border-bottom: 1px solid #BAC9CF;
}





/* nested sortables additions (originally from Zenpage)
-------------------------------------*/
table.bordered2 {
	width: 100%;
	padding: 0px;
	border-spacing: 0px;
	margin: 0px;
	background: #F7F8F9;
	border-top: 1px solid #F7F8F9; /*#BAC9CF; */
	border-bottom: 1px solid #F7F8F9; /*#BAC9CF; */
}

table.bordered2 td {
	padding: 4px 16px;
	margin: 0px;
	background-color: #fff;
}


.page-list {
	list-style: none;
	margin: 0;
	padding: 0;
	display: block;
}
ul.page-list, ul.page-list ul {
	margin: 0 0 0 20px;
	padding: 0;
	list-style-type: none;
}

ul.page-list {
	margin: 2.5em 0 1.5em 0;
}

.page-list li {
	margin: 0px 0 0 0;
	padding: 0;
}

.page-list li table {
	border: 0;
	padding: 0px;
	margin: 0;
	cursor: move;
}

.placeholder {
	background-color: #cfcfcf;
}

.ui-nestedSortable-error {
	background: red; /*#fbe3e4;*/
	color: #8a1f11;
}

.bold {
	color: red;
	font-weight: bold;
}

/* TABLELESS SORTING TESTS
********************************************/

div.bordered {
	width: 100%;
	padding: 0px;
	border-spacing: 0px;
	background-color: white;
	border: 1px solid #E5E5E5;
	border-bottom-width: 5px;
	-moz-border-radius: 5px;
	-khtml-border-radius: 5px;
	-webkit-border-radius: 5px;
	border-radius: 5px;
}

div.bordered .headline {
	font-weight: bold;
	padding: 8px 10px 13px 10px;
	border-bottom: 2px solid #cccccc;
	background: #ECF1F2;
	background-image: url(../images/admin-headlineback.jpg);
	background-repeat: repeat-x;
	vertical-align: middle;
}

div.bordered .subhead  {
	padding-top: 5px;
	padding-right: 20px;
}


div.bordered .page-list_row {
	width: 100%;
	height: 50px;
	background-color: white !important;
	border-top: 1px solid #F7F8F9 !important;
	border-bottom: 1px solid #F7F8F9 !important;
}

div.bordered .page-list_row .page-list_title {
	float: left;
	width: 20%;
	height: 30px;
	padding: 20px 0px 0px 45px;
	background-image: url(../images/drag_handle.png) !important;
	background-repeat: no-repeat;
	background-position: 15px 20px;

}
div.bordered .page-list_row .page-list_albumthumb {
	float: left;
	width: 50px;
	height: 45px;
	padding: 5px 0px 0px 45px;
	background-image: url(../images/drag_handle.png) !important;
	background-repeat: no-repeat;
	background-position: 15px 20px;
}

div.bordered .page-list_row .page-list_albumthumb img {

}


div.bordered .page-list_row .page-list_albumtitle {
	float: left;
	width: 25%;
	height: 30px;
	padding: 20px 0px 0px 10px;

}

div.bordered .page-list_row .page-list_extra {
	float: left;
	padding-top: 20px;
	margin-right: 20px;
}

div.bordered .page-list_row .page-list_extra a img {
	border: 0;
}

div.bordered .page-list_row .page-list_extra > span,
div.bordered .page-list_row .page-list_extra > a > span {
	position: relative;
	top: -3px;
}

div.bordered .page-list_row .page-list_iconwrapper,
div.bordered .page-list_row .page-list_iconwrapperalbum {
	text-align: right;
	float: right;
	padding-top: 18px;
	margin-right: 10px;
}

div.bordered .page-list_row .page-list_icon {
	display: inline;
	margin-right: 20px;
}


div.bordered .page-list_row .page-list_icon .checkbox {
	display: inline;
	position: relative;
	top: -4px;
}


/* helper classes */
.floatright {
	float: right !important;
}

.floatleft {
	float: left !important;
}

img.zp_logoicon {
	position: relative;
	top: 3px;
}

/* background-color for currently selected items */
.currentselection,
tr.currentselection td {
	background-color: #ECF1F2 !important;
}

/* background-color for "shown" plugins */
.highlightselection,
tr.highlightselection td {
	background-color: #D4DBDB !important;
}


.clearall {
	clear: both !important;
}
.clearleft {
	clear: left !important;
}
.clearright {
	clear: right !important;
}

/*
Tooltip styling
************************************/
.ui-tooltip, .arrow:after {
	background: #f5f5f5;
  border: 2px solid #4D4D4D;
}
.ui-tooltip {
  padding: 10px 20px;
  color: black;
  border-radius: 20px;
  font: 14px "Helvetica Neue", Sans-Serif;
  box-shadow: 0 0 7px black;
  text-align:left;
	background: #f5f5f5;
}
.arrow {
  width: 70px;
  height: 16px;
  overflow: hidden;
  position: absolute;
  left: 50%;
  margin-left: -35px;
  bottom: -16px;
}
.arrow.top {
  top: -16px;
  bottom: auto;
}
.arrow.left {
  left: 20%;
}
.arrow:after {
  content: "";
  position: absolute;
  left: 20px;
  top: -20px;
  width: 25px;
  height: 25px;
  box-shadow: 6px 5px 9px -9px black;
  -webkit-transform: rotate(45deg);
  -moz-transform: rotate(45deg);
  -ms-transform: rotate(45deg);
  -o-transform: rotate(45deg);
  tranform: rotate(45deg);
}
.arrow.top:after {
  bottom: -20px;
  top: auto;
}


#form_editcomment label {
	width: 30% !important;
	float: left;
	display: block;
}

#form_editcomment input {
	width: 60% !important;
}


#form_editcomment textarea {
	clear: both !important;
	display: block;
	width: 100% !important;
}


.commentformedit_fields {
	width: 60%;
	float: left;
}

.commentformedit_box {
	width:260px;
	float:right;
}

/* prevent jumping toolbar buttons of TinyMCE4 in some browsers */
.mce-container .mce-toolbar button {
	border: 0 !Important;
	-webkit-box-sizing: border-box;
	-moz-box-sizing: border-box;
	-o-box-sizing: border-box;
	-ms-box-sizing: border-box;
	box-sizing: border-box;
}


/* thumb albumsort */
#images,
#images li {
	display: inline;
	margin: 0;
	padding: 0;
}

#images li {
	list-style-type: none;
	float: left;
	margin: 0 8px 8px 0;
	position: relative;
}

#images li p {
	margin: -5px 0 0 0 !important;
	padding: 0;
}

#images .images_publishstatus {
	position: absolute;
	top: 2px;
	right: 2px;
	background: rgba(0,0,0,0.5);
	padding: 0 1px 0 1px;
	line-height: 1em;
}

/* definition lists */

dl {
	display: block;
	clear: both;
	width: 100%;
}

dt,dd {
	display: inline-block;
	width: 35%;
	margin: 0;
	padding: 5px;
}

dt {
	font-weight: bold;
}

.bar {
	background: #f0f0f0;
}

dd {
	width: 60%;
	margin-left: -10px;
}

.top {
	vertical-align: top;
}

ul.userlist {
	clear: both;
	padding: 0;
	margin: 0px;
	list-style-type: none;
}


form.dirty button[type=submit],
form.dirty input[type=submit] {
	border: 1px solid #74b341 !important;
	background: #d7e5a6;
}

form.dirty button[type=submit]:hover,
form.dirty button[type=submit]:active,
form.dirty input[type=submit]:hover,
form.dirty input[type=submit]:active{
	border: 1px solid green !important;
	background: #eff6d5;
}

.hidden {
	display: none;
}

.clearfix:before,
.clearfix:after {
  content: " " !important;
  display: table !important; 
}

.clearfix:after {
  clear: both !important; 
}

.language_string_listbox,
.zenpage_language_string_listbox {
	resize: vertical !important;
	overflow: scroll;
}

/* scheduled publishing
--------------------------*/
.scheduledpublishing {
	color: orange !important;
	font-weight: normal;
}

.scheduledate {
	color: orange !important;
	font-weight: normal;
}

.inactivescheduledate {
	color: lightsalmon !important;
	font-weight: normal;
}

.expiredate {
	color: blue !important;
	font-weight: normal;
}

.expire,
.expired {
	color: red !important;
	font-weight: normal;
}

/* album edit additions 
--------------------------- */

.adminedit_fullimagelink {
	position: relative;
	display: inline-block;
	width: 100%;
}

.adminedit_fullimagelink img {

}

.adminedit_fullimage-icon {
	position: absolute;
	top: 0px;
	left: 0px;
	padding: 3px;
	z-index: 1000;
	background: white;
}


/* various
----------------------_*/
.optionlist {
	list-style: none;
	padding:0;
	margin: 0;

}

.optionlist li {
	list-style: none;
	padding-left: 0;
}


#resizble {
	resize: vertical;
}