<?php

// force UTF-8 Ø

// Zenphoto theme definition file
$theme_description['name'] = 'zpMobile';
$theme_description['author'] = gettext('Malte Müller (acrylian)');
$theme_description['version'] = true;
$theme_description['date'] = true;
$theme_description['desc'] = gettext("A theme primarily meant for mobile/smartphone browsing using <a href='http://jQuerymobile.com'>jQuerymobile framework</a>.");
$theme_description['deprecated'] = true;
?>
