@font-face {
	font-family: 'cycle2-icons';
	src:url('cycle2-icons.eot');
	src:url('cycle2-icons.eot?#iefix') format('embedded-opentype'),
		url('cycle2-icons.ttf') format('truetype'),
		url('cycle2-icons.woff') format('woff'),
		url('cycle2-icons.svg#cycle2-icons') format('svg');
	font-weight: normal;
	font-style: normal;
}

.slideshow .icon-play,
.slideshow .icon-pause,
.slideshow .icon-arrow-down,
.slideshow .icon-stop,
.slideshow .icon-arrow-right,
.slideshow .icon-backward,
.slideshow .icon-arrow-up,
.slideshow .icon-forward,
.slideshow .icon-arrow-left {
	font-family: 'cycle2-icons';
	speak: none;
	font-style: normal;
	font-weight: normal;
	font-variant: normal;
	text-transform: none;
	line-height: 1;

	/* Better Font Rendering =========== */
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale;
}

.slideshow .icon-play:before {
	content: "\e600";
}
.slideshow .icon-pause:before {
	content: "\e601";
}
.slideshow .icon-arrow-down:before {
	content: "\e605";
}
.slideshow .icon-stop:before {
	content: "\e602";
}
.slideshow .icon-arrow-right:before {
	content: "\e606";
}
.slideshow .icon-backward:before {
	content: "\e603";
}
.slideshow .icon-arrow-up:before {
	content: "\e607";
}
.slideshow .icon-forward:before {
	content: "\e604";
}
.slideshow .icon-arrow-left:before {
	content: "\e608";
}
