span.tagMatches { 
	width: 100%;
	display: block;
	position: absolute;
	z-index: 100;
	max-height: 300px;
	text-align: left;
	overflow: auto;
	border: 0;
	top: 19px;
	left: 0;
} 
    
span.tagMatches span { 
	color: black;
	cursor: pointer; 
	width: 100%;
	display: block;
	background-color: #F5F5F3; 
	padding: 5px;
} 

._tag_suggestion {
	float: left; 
	width: 100%;
	display: block;
}

.tagSuggestContainer {
	position: relative;
	width: 90%;
	display: inline-block;
}
