<?php
/**
 * stand-in for when there is no HTML cache plugin enabled
 * @package zpcore\classes\helpers
 */
class _zp_HTML_cache {

	function disable() {
		
	}

	function startHTMLCache() {
		
	}

	function abortHTMLCache() {
		
	}

	function endHTMLCache() {
		
	}

	function clearHtmlCache() {
		
	}

}