/* Clear Outer Styles */

body {
	margin-top: 32px !important;
}
#zp__admin_module * {
	font-family: Helvetica, Arial, sans-serif !important;
	font-size: 16px !important;
	line-height: 15px !important;
	font-weight: normal;
}

#zp__admin_module {
	text-align: left;
	position: fixed;
	left: 0px;
	top: 0px;
	border: 0px solid rgba(0,0,0,0.15);
	border-radius: 3px;
	background: rgba(255,255,255,0.9);
	height: 30px;
	z-index: 100001;
	box-shadow: 0 1px 0 rgba(0,0,0,0.1);
	width: 100%;
}

#zp__admin_info {
	position: absolute;
	left: 0;
	top: 0;
	background: transparent;
	display: block;
}

#zp__admin_info .zp_logo {
	color: white !important;
	float: left;
	display: inline-block;
	background:gray;
	-moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  -o-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box; 
	padding: 8px 4px 8px 4px; 
	width: 30px !important;
	height: 30px !important;
	text-align: center;
	font-size: 13px !important;
}

#zp__admin_info .zp_user {
	float: left;
	display: inline-block;
	padding: 7px 0 0 6px;
	font-size: 15px !important;
	white-space: nowrap;
	font-weight: normal;
	color: slategrey;
}

#zp__admin_info .zp_sitestatus {
 color: red;
 font-weight: bold;
}

#zp__admin_link {
	font-weight: bold;
	color: #999;
	font-size: 15px !important;
	position: relative;
	position: absolute;
	right: 0;
	top: 0;
	padding: 4px 8px;
	background: rgba(255,255,255,0.9);
	border: 1px solid rgba(0,0,0,0.15);
	display: block;
	text-decoration: none;
	white-space: nowrap;
}

#zp__admin_link:hover,
#zp__admin_link:focus,
#zp__admin_link:active {
	color: #0CF !important;
	background-color: white;
	border-color: rgba(0,0,0, 0.2);
	cursor: pointer;
}

#zp__admin_data {
	z-index: 10000;
	background: rgba(255,255,255,0.95);
	line-height: 16px;
	width: 260px !important;
	padding-top: 30px;
	float: right;
}


#zp__admin_data ul, 
#zp__admin_data li {
	padding: 0;
	margin: 0;
	list-style: none;
}

#zp__admin_data li {
 border-top: 1px solid lightgray;
}

#zp__admin_data li ul {
	border-top: 1px solid lightgray;
	border-bottom: 1px solid lightgray;
}

#zp__admin_data button,
#zp__admin_data a {
	text-decoration: none;
	color: #09C;
	display: block;
	padding: 8px;
	border: 0;
	background: white;
	width: 100%;
	text-align: left;
}
#zp__admin_data button:hover,
#zp__admin_data button:focus,
#zp__admin_data button:active,
#zp__admin_data a:hover,
#zp__admin_data a:focus,
#zp__admin_data a:active {
	color: #0CF;
	background-color: #E3E6E9;
	cursor: pointer;
}

#zp__admin_data button.admin_data-delete {
	color: red;
}

#zp__admin_data button.admin_data-delete:hover,
#zp__admin_data button.admin_data-delete:focus,
#zp__admin_data button.admin_data-delete:active {
	color: red;
}

/* Transitions */
#zp__admin_link a {
	transition: all 0.1s ease-out;
	-moz-transition: all 0.1s ease-out;
	-webkit-transition: all 0.1s ease-out;
}

@media only screen and (max-width: 767px) {
	#zp__admin_data {
		
	}
}

@media only screen and (max-width: 479px) {
	#zp__admin_data {
		width: 100% !important;
	}
}
