.jcarousel-container {
    background: white;
    width: 440px;
    height: 65px;
    padding: 0px;
    margin: 0 auto;
}

.jcarousel-clip {
    width:  390px;
    height: 65px;
    margin: 0 auto;
}

.jcarousel-list {
	border: 0px solid darkgray;
    width:  150px;
    height: 75px;
    margin-top: 0px;
}

.jcarousel-list li {
    width: 55px;
    height:75px;
    margin-right: 5px;
    margin-left: 5px;
    
    
}

.jcarousel-list li .activecarouselimage {
	border: 2px solid orange !important;
	padding: 1px;
}


.jcarousel-item-placeholder {
    background: #fff url(images/jcarousel_loading.gif) 50% 50% no-repeat;
}

/**
 *  Horizontal Buttons
 */
.jcarousel-next-horizontal {
    position: absolute;
    top: 10px;
    right: -20px;
    width: 32px;
    height: 32px;
    cursor: pointer;
    background: transparent url(images/jcarousel_next.png) no-repeat 0 0;
}

.jcarousel-next-horizontal:hover {
    background-position: -32px 0;
}

.jcarousel-next-horizontal:active {
    background-position: -64px 0;
  }

.jcarousel-next-disabled-horizontal,
.jcarousel-next-disabled-horizontal:hover,
.jcarousel-next-disabled-horizontal:active {
    cursor: default;
    background-position: -96px 0;
}

.jcarousel-prev-horizontal {
    position: absolute;
    top: 10px;
    left: -20px;
    width: 32px;
    height: 32px;
    cursor: pointer;
    background: transparent url(images/jcarousel_prev.png) no-repeat 0 0;
}

.jcarousel-prev-horizontal:hover {
    background-position: -32px 0;
}

.jcarousel-prev-horizontal:active {
    background-position: -64px 0;
}

.jcarousel-prev-disabled-horizontal,
.jcarousel-prev-disabled-horizontal:hover,
.jcarousel-prev-disabled-horizontal:active {
    cursor: default;
    background-position: -96px 0;
}

